/*
 * libosinfo:
 *
 * Copyright (C) 2009-2012 Red Hat, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * Authors:
 *   Arjun Roy <arroy@redhat.com>
 *   Daniel P. Berrange <berrange@redhat.com>
 */

#ifndef __OSINFO_H__
#define __OSINFO_H__

#include <glib-object.h>

#include <osinfo/osinfo_enum_types.h>
#include <osinfo/osinfo_entity.h>
#include <osinfo/osinfo_filter.h>
#include <osinfo/osinfo_list.h>
#include <osinfo/osinfo_device.h>
#include <osinfo/osinfo_device_driver.h>
#include <osinfo/osinfo_device_driverlist.h>
#include <osinfo/osinfo_devicelink.h>
#include <osinfo/osinfo_devicelist.h>
#include <osinfo/osinfo_devicelinklist.h>
#include <osinfo/osinfo_devicelinkfilter.h>
#include <osinfo/osinfo_install_config.h>
#include <osinfo/osinfo_install_config_param.h>
#include <osinfo/osinfo_install_script.h>
#include <osinfo/osinfo_avatar_format.h>
#include <osinfo/osinfo_install_scriptlist.h>
#include <osinfo/osinfo_productlist.h>
#include <osinfo/osinfo_product.h>
#include <osinfo/osinfo_productfilter.h>
#include <osinfo/osinfo_platformlist.h>
#include <osinfo/osinfo_platform.h>
#include <osinfo/osinfo_oslist.h>
#include <osinfo/osinfo_os.h>
#include <osinfo/osinfo_deploymentlist.h>
#include <osinfo/osinfo_deployment.h>
#include <osinfo/osinfo_media.h>
#include <osinfo/osinfo_medialist.h>
#include <osinfo/osinfo_resources.h>
#include <osinfo/osinfo_resourceslist.h>
#include <osinfo/osinfo_tree.h>
#include <osinfo/osinfo_treelist.h>
#include <osinfo/osinfo_db.h>
#include <osinfo/osinfo_loader.h>

#endif
/*
 * Local variables:
 *  indent-tabs-mode: nil
 *  c-indent-level: 4
 *  c-basic-offset: 4
 * End:
 */
